@@ -97,9 +97,13 @@ class FacebookCall(object):
         except ValueError:
             return data
 
-        if 'error' in response_obj:
-            raise FacebookError(message=response_obj.error.message,
-                    err=response_obj.error.type, code=response.code)
+        try:
+            if 'error' in response_obj:
+                raise FacebookError(message=response_obj.error.message,
+                        err=response_obj.error.type, code=response.code)
+        except TypeError:
+            # Response was probably a bool
+            pass
 
         return response_obj
 
